@@ -1,32 +1,35 @@
 from time import sleep
+from typing import Callable, Iterator
 
 import pytest
 
 
-def create_virtual_environment():
+def create_virtual_environment() -> None:
     sleep(0.001)
 
 
-def start_server():
+def start_server() -> None:
     sleep(0.001)
 
 
-def parallel_requests():
+def parallel_requests() -> None:
     sleep(0.001)
 
 
 @pytest.fixture(scope="session")
-def expensive_setup(printer_session):
+def _expensive_setup(printer_session: Callable[[str], None]) -> Iterator[None]:
     printer_session("attempt global peace")
     yield
     printer_session("teardown global peace")
 
 
-def test_global_peace(printer_session, expensive_setup):
+@pytest.mark.usefixtures("_expensive_setup")
+def test_global_peace(printer_session: Callable[[str], None]) -> None:
     printer_session("here we have global peace")
 
 
-def test_server_parallel_requests(printer, tmpdir, expensive_setup):
+@pytest.mark.usefixtures("_expensive_setup")
+def test_server_parallel_requests(printer: Callable[[str], None]) -> None:
     printer("create virtual environment")
     create_virtual_environment()
 
